
###################################################################################
#      print data in the .dat calculation file (instead of a classic .bas template)
proc Cmas2d::WriteCalculationFile { filename } {
    customlib::InitWriteFile $filename
    set elements_solids [list "Solids"]
	set elements_joints [list "Joints"]
	# This instruction is mandatory for using materials
    customlib::InitMaterials $elements_solids active
	
	#################### GENERAL DATA ############################ 
    customlib::WriteString "(1) nod,nodb,nodj,nels,nelsj,nn,nip,nipb,np_types,np_typesj"
	customlib::WriteString " 8 4 8 [GiD_Info Mesh NumElements Hexahedra] [GiD_Info Mesh NumElements Quadrilateral] [GiD_Info Mesh NumNodes] 8 4 1"
	customlib::WriteString "(2) # of time steps, convergence limit for nonlinear calculations"
    #################### COORDINATES ############################ 
    set units_mesh [gid_groups_conds::give_mesh_unit]
    customlib::WriteString "(3) Coordinates:  Node        X $units_mesh               Y $units_mesh      Z $units_mesh"      
    # Write all nodes of the model, and it's coordinates
    # Check documentation to write nodes from an specific condition
    # Example for 3D case
    customlib::WriteCoordinates "%5d %14.5e %14.5e %14.5e\n"
    #################### CONNECTIVITIES % MATERIALS ############################    
    customlib::WriteString "(4) Element connectivities for solid elements"
    set element_formats [list {"%10d" "element" "id"} {"%10d" "element" "connectivities"} {"%10d" "material" "MID"}]
    customlib::WriteConnectivities $elements_solids $element_formats active	
	
	set num_materials [customlib::GetNumberOfMaterials used]
    customlib::WriteString "(5) Material:      Surface density [gid_groups_conds::give_active_unit M/L^2]"
	customlib::WriteString $num_materials
    customlib::WriteMaterials [list {"%4d" "material" "MID"} {"%13.5e" "material" "Young"}] used active
	#customlib::InitMaterials $elements_solids inactive
	# Joint elements
    customlib::InitMaterials $elements_joints active
	customlib::WriteString "(6) Element connectivities for joint elements"
    set joint_formats [list {"%10d" "element" "id"} {"%10d" "element" "connectivities"} {"%10d" "material" "MID"}]
	customlib::WriteConnectivities $elements_joints $joint_formats active
	
	set num_materials [customlib::GetNumberOfMaterials used]
    customlib::WriteString "(7) Material:      Surface density [gid_groups_conds::give_active_unit M/L^2]"
	customlib::WriteString $num_materials
    #customlib::WriteMaterials [list {"%4d" "material" "MID"} {"%13.5e" "material" "ks1"}] used active
	
    
    #################### CONCENTRATE WEIGHTS ############################
    customlib::WriteString ""
    customlib::WriteString "................................................................."
    customlib::WriteString ""
    set list1 [list "Disp_Bc"]
    set condition_formats [list {"%1d" "node" "id"} {"%1d" "property" "Iffix_x"} {"%1d" "property" "Iffix_y"} {"%1d" "property" "Iffix_z"}]
    set number_of_conditions [customlib::GetNumberOfNodes $list1]
    customlib::WriteString "Displacement Boundary Conditions"
	customlib::WriteString "nffix/Iffix   ifix_x  ifix_y ifix_z"
    customlib::WriteString $number_of_conditions
    customlib::WriteNodes $list1 $condition_formats "" active
	
	customlib::WriteString "Traction Boundary Conditions"
	customlib::WriteString "nsurface/ie  Tn "
	#set list2 [list "Trac_Bc"]
	#set condition_formats [list {"%10d" "element" "id"} {"%10d" "element" "connectivities"} {"%13.5e" "property" "Tn"}]
	#set formats [customlib::GetElementsFormats $list2 $condition_formats]
	#set number_of_loaded_elements [GiD_WriteCalculationFile elements -count $formats]
    #customlib::WriteConnectivities $list2 $formats "" active
	
	
    customlib::EndWriteFile ;#finish writting
}
